Skip to contents

Run a baseline RW/slice configuration (sequential)

Usage

run_baseline_config(
  build_fn,
  niter,
  nburnin = floor(0.25 * niter),
  thin = 1L,
  monitors = NULL,
  nchains = 1L,
  opts = samOptiPro_options()
)

Arguments

build_fn

Function with no arguments that returns a list with at least model, cmodel and conf, or a builder that is passed to an internal fresh-build wrapper.

niter

Total number of MCMC iterations.

nburnin

Number of initial iterations discarded as burn-in.

thin

Thinning interval (keep 1 draw every thin iterations).

monitors

Optional character vector of monitor roots; if NULL, default monitors are inferred.

nchains

Integer; number of chains to run in runMCMC.

opts

List of options as returned by samOptiPro_options().

Value

A list with components samples, samples2, runtime_s and conf.